@@ -7,7 +7,9 @@ use App::Fasops -command;
 use App::RL::Common;
 use App::Fasops::Common;
 
-use constant abstract => 'concatenate sequence pieces in blocked fasta files';
+sub abstract {
+    return 'concatenate sequence pieces in blocked fasta files';
+}
 
 sub opt_spec {
     return (
@@ -25,10 +27,15 @@ sub usage_desc {
 sub description {
     my $desc;
     $desc .= ucfirst(abstract) . ".\n";
-    $desc .= "\t<infile> is the path to blocked fasta file, .fas.gz is supported.\n";
-    $desc .= "\tinfile == stdin means reading from STDIN\n";
-    $desc .= "\t<name.list> is a file with a list of names to keep, one per line.\n";
-    $desc .= "\tNames in the output file will following the order in <name.list>.\n";
+    $desc .= <<'MARKDOWN';
+
+* <infile> is the path to blocked fasta file, .fas.gz is supported
+* infile == stdin means reading from STDIN
+* <name.list> is a file with a list of names to keep, one per line
+* Names in the output file will following the order in <name.list>
+
+MARKDOWN
+
     return $desc;
 }
 
@@ -96,7 +103,7 @@ sub execute {
                         $all_seq_of->{$name} .= $info_of->{$name}{seq};
                     }
                     else {
-                        # fill unpresented names with ------
+                        # fill absent names with ------
                         $all_seq_of->{$name} .= '-' x $align_length;
                     }
                 }
