@@ -7,7 +7,9 @@ use App::Fasops -command;
 use App::RL::Common;
 use App::Fasops::Common;
 
-use constant abstract => 'extract a subset of species from a blocked fasta';
+sub abstract {
+    return 'extract a subset of species from a blocked fasta';
+}
 
 sub opt_spec {
     return (
@@ -25,10 +27,15 @@ sub usage_desc {
 sub description {
     my $desc;
     $desc .= ucfirst(abstract) . ".\n";
-    $desc .= "\t<infile> is the path to blocked fasta file, .fas.gz is supported.\n";
-    $desc .= "\tinfile == stdin means reading from STDIN\n";
-    $desc .= "\t<name.list> is a file with a list of names to keep, one per line.\n";
-    $desc .= "\tNames in the output file will following the order in <name.list>.\n";
+    $desc .= <<'MARKDOWN';
+
+* <infile> is the path to blocked fasta file, .fas.gz is supported
+* infile == stdin means reading from STDIN
+* <name.list> is a file with a list of names to keep, one per line
+* Names in the output file will following the order in <name.list>
+
+MARKDOWN
+
     return $desc;
 }
 
